# Sujet n° 14 : Pavage hexagonal avec voisinage géométrique

*Encadrant :* Frédéric Serin

Ce sujet sera proposé avec un code Java opérationnel permettant de déterminer un pavage hexagonal.

Le travail attendu sera :
  * une amélioration de la qualité du code et en particulier sa généralisation ;
  * la création d'un outil de navigation parmi les territoires générés ;
  * la présentation formalisée du problème.

Vous savez qu'il n'existe que trois figures géométriques régulières qui permettent de paver entièrement le plan : le triangle équilatéral, le carré et l'hexagone régulier. Ce dernier, faisant écho aux travaux du géographe Walter Christaller au début du XXe siècle est fort intéressant car s'approchant du disque par sa forme.

En particulier avec le jeu de la vie de Conway, vous connaissez sans doute le voisinage de Moore qui permet de déterminer les voisins d'une cellule. Ils sont au nombre de huit pour une cellule carrées et de six pour une cellule hexagonale.

La définition de voisinage renvoie à celle de proximité. Il existe ainsi d'autres voisinages. Les proximités de Von Neumann et de Moore sont, de 1, une distance de contact (si on considère que 0 sera la figure elle-même). Une distance ou proximité de 2 donnera un voisinage différent. Cette proximité consiste à prendre les voisines de la figure et les voisines des voisines. Pour un carré, et selon Moore, il y aura alors dans ce cas, 24 voisines. En généralisant, le voisinage de Moore d'ordre n est constitué des cellules qui l'entourent à une distance de Tchebychev de n. La distance de Pafnouti Tchebychev est la distance entre deux points donnée par la différence maximale entre leurs coordonnées sur une dimension.

## Représentation de voisinages géométriques avec un pavage hexagonal.

Dans la figure ci-après, nous avons dessiné un hexagone et ses six voisins. On constate que les voisinages de Moore et de Von Neumann sont exactement identiques avec cette figure géométrique.

<center>
![Territoire représenté par sept hexagones](02FCS-7-T1.svg)

Fig 1 - Territoire représenté par sept hexagones
</center>

Nous ne voulons pas d'une progression arithmétique mais géométrique de l'ordre des voisinages. Autrement dit, autour de ce territoire de sept hexagones, le voisinage n'est pas une couronne d'hexagones limitrophes mais des six territoires de taille équivalente (T1 de sept hexagones).

<center>
![Six voisins T1 forment ainsi un territoire T2](02FCS-49-T2.svg)

Fig 2 - Six voisins T1 forment ainsi un territoire T2
</center>

Ces générations sont rendues possibles avec le code Java qui sera fourni.

En fait, nous pouvons obtenir deux solutions, selon que le voisinage géométrique ainsi défini sera généré dans un sens (horaire) ou un autre (anti-horaire).

On obtient un plus grand territoire, constitué de 49 hexagones. Sur le même principe, on peut déterminer des territoires voisins ayant cette même dimension, de 49 hexagones ? On obtiendrait un territoire de 343 hexagones.

Nous pouvons qualifier ces divers territoires de type T1 (7 hexagones), T2 (49 hexagones), T3 (343), et ainsi de suite. Inversement, nous pouvons dire qu'un simple hexagone est un territoire de type T0.

Nous pouvons dire, de façon générale, qu'un territoire Tn possède six voisins de type Tn. Cela forme globalement un territoire T(n+1).

On peut ainsi définir un voisinage qui n'est plus arithmétique comme avec la distance de Tchebychev mais géométrique. Ainsi, le voisinage géométrique d'ordre un serait constitué de 6 hexagones, le voisinage d'ordre 2 de 48, d'ordre 3 de 342, etc.

<center>
![Territoire T3 constitué de sept T2](02FCS-343_T3.svg)

Fig 3 - Territoire T3 constitué de sept T2
</center>

## Modélisation des territoires

On peut définir un modèle objet qui représente d'une part un hexagone comme la figure de base, possédant une dimension, des coordonnées spatiales, et, d'autre part, des territoires définis comme composés de territoires de rang juste inférieur. Un territoire T2 étant composé de sept territoires T1.

Ce diagramme compte 3 classes et 1 association.

<center>
![Territoires T0 (hexagone) et Tn](diagclasse-fig4-FSerin_TPE_HEXA_2022.svg)

Fig 4 - Territoires T0 (hexagone) et Tn
</center>

Dans ce schéma, on indique clairement que tout territoire sera composé de sept figures. Le losange plein, accolé à la classe Territoire, précise qu'un territoire est composé de figures, une figure (classe abstraite) est, par spécialisation, soit un hexagone, soit un territoire (entendez par là, un territoire de type T1, T2 ou supérieur). EN fait, un territoire de type Tn est composé de sept territoires de type T(n-1), sachant qu'un hexagone sera réputé de type T0. Bien entendu, la composition étant sur un territoire Tn, cela implique que n≥1.

## Améliorations

La représentation sous forme d'hexagones du pavage est une approche aérolaire. Une représentation réticulaire consistera à considérer les côtés et sommets autour d'un hexagone. Le maillage avec les côtés représente le même dessin.

On peut aussi s'intéresser au graphe dual, un graphe dont les sommets sont le centre de chaque hexagone. Chaque segment relie alors les centres de deux hexagones limitrophes. le maillage obtenu est alors constitué de mailles triangulaires.

Le triangle équilatéral prend alors toute son importance, d'autant qu'un hexagone est, lui aussi, une forme constituée de six triangles dont le centre est le sommet commun.

Ainsi, alors qu'un hexagone ne peut se décomposé en plus petits hexagones, nous verrons que ces deux approches permettent de reconstituer des hexagones en passant par l'intermédiaire de triangles.

Une des versions qui sera visée particulièrement est de considérer la division en sept d'un triangle, c'est à dire de décomposer un triangle — un sixième d'hexagone — en 49 petits triangles. En reconstituant à partir de cette décomposition de plus petits hexagones, on s'apercevra qu'un hexagone se rapproche fortement de la forme d'un territoire T2, à une différence près qui donne les deux configurations de voisinage géométrique possible. On pourra ainsi démontrer la faisabilité du pavage complet géométrique.

## Résultat

Divers éléments seront fournis dont une première trame pour permettre la navigation dynamique entre types de territoires.

Une base de données sobre et simpliste, de type CSV, sera à mettre en œuvre.

Les étudiants devront avoir une bonne connaissance de Java et HTML. Du code SVG sera fourni, simplifiant son appropriation.

L'introduction de javascript sera autorisée au besoin.

L'idée est de facilité l'appropriation d'un territoire de taille variable en permettant des zooms avant ou arrière, une navigation de proche en proche, à partir d'un modèle utilisant soit les propriétés des liens hypertextes, soit une approche avec Javascript.
